from setuptools import setup, find_packages

setup(
    name='ezga',
    version='0.1.0',
    description='Easy Genetic Algorithm library',
    author='Your Name',
    author_email='your_email@example.com',
    url='https://github.com/yourusername/ezga',
    packages=find_packages(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    keywords='genetic algorithm optimization',
    python_requires='>=3.6',
)

